@@ -113,9 +113,20 @@ class Jira(AtlassianRestAPI):
             username=username, include_inactive=include_inactive_users, start=start, limit=limit)
         return self.get(url)
 
-    def projects(self):
+    def projects(self, included_archived=None):
+        """Returns all projects which are visible for the currently logged in user.
+        If no user is logged in, it returns the list of projects that are visible when using anonymous access.
+        :param included_archived: boolean whether to include archived projects in response, default: false
+        :return:
+        """
+        params = {}
+        if included_archived:
+            params['includeArchived'] = included_archived
         return self.get('rest/api/2/project')
 
+    def get_all_projects(self, included_archived=None):
+        return self.projects(included_archived)
+
     def project(self, key):
         return self.get('rest/api/2/project/{0}'.format(key))
 
@@ -175,6 +186,24 @@ class Jira(AtlassianRestAPI):
     def update_issue_field(self, key, fields='*all'):
         return self.put('rest/api/2/issue/{0}'.format(key), data={'fields': fields})
 
+    def get_custom_fields(self, search=None, start=1, limit=50):
+        """
+        Get custom fields. Evaluated on 7.12
+        :param search: str
+        :param start: long Default: 1
+        :param limit: int Default: 50
+        :return:
+        """
+        url = 'rest/api/2/customFields'
+        params = {}
+        if search:
+            params['search'] = search
+        if start:
+            params['startAt'] = start
+        if limit:
+            params['maxResults'] = limit
+        return self.get(url, params=params)
+
     def project_leaders(self):
         for project in self.projects():
             key = project['key']
@@ -224,6 +253,38 @@ class Jira(AtlassianRestAPI):
             limit=limit)
         return self.get(url)
 
+    def create_group(self, name):
+        """
+        Create a group by given group parameter
+
+        :param name: str
+        :return: New group params
+        """
+        url = 'rest/api/2/group'
+        data = {'name': name}
+
+        return self.post(url, data=data)
+
+    def remove_group(self, name, swap_group=None):
+        """
+        Delete a group by given group parameter
+        If you delete a group and content is restricted to that group, the content will be hidden from all users
+        To prevent this, use this parameter to specify a different group to transfer the restrictions
+        (comments and worklogs only) to
+
+        :param name: str
+        :param swap_group: str
+        :return:
+        """
+        log.warning('Removing group...')
+        url = 'rest/api/2/group'
+        if swap_group is not None:
+            params = {'groupname': name, 'swapGroup': swap_group}
+        else:
+            params = {'groupname': name}
+
+        return self.delete(url, params=params)
+
     def get_all_users_from_group(self, group, include_inactive_users=False, start=0, limit=50):
         """
         Just wrapping method user group members
@@ -239,6 +300,34 @@ class Jira(AtlassianRestAPI):
             group=group, include_inactive=include_inactive_users, start=start, limit=limit)
         return self.get(url)
 
+    def add_user_to_group(self, username, group_name):
+        """
+        Add given user to a group
+
+        :param username: str
+        :param group_name: str
+        :return: Current state of the group
+        """
+        url = 'rest/api/2/group/user'
+        params = {'groupname': group_name}
+        data = {'name': username}
+
+        return self.post(url, params=params, data=data)
+
+    def remove_user_from_group(self, username, group_name):
+        """
+        Remove given user from a group
+
+        :param username: str
+        :param group_name: str
+        :return:
+        """
+        log.warning('Removing user from a group...')
+        url = 'rest/api/2/group/user'
+        params = {'groupname': group_name, 'username': username}
+
+        return self.delete(url, params=params)
+
     def issue_exists(self, issue_key):
         try:
             self.issue(issue_key, fields='*none')
